==> io.janusproject.plugin-0.5.3-sources.jar: io/janusproject/kernel/services/zeromq/Messages.java <==
/*
 * $Id$
 *
 * SARL is an general-purpose agent programming language.
 * More details on http://www.sarl.io
 *
 * Copyright (C) 2014-2017 the original authors or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.janusproject.kernel.services.zeromq;

import org.eclipse.osgi.util.NLS;

/** Messages.
 * @author $Author: sgalland$
 * @version $FullVersion$
 * @mavengroupid $GroupId$
 * @mavenartifactid $ArtifactId$
 */
@SuppressWarnings("all")
public class Messages extends NLS {
	private static final String BUNDLE_NAME = "io.janusproject.kernel.services.zeromq.messages"; //$NON-NLS-1$
	public static String ZeroMQNetworkService_0;
	public static String ZeroMQNetworkService_1;
	public static String ZeroMQNetworkService_10;
	public static String ZeroMQNetworkService_11;
	public static String ZeroMQNetworkService_12;
	public static String ZeroMQNetworkService_13;
	public static String ZeroMQNetworkService_14;
	public static String ZeroMQNetworkService_15;
	public static String ZeroMQNetworkService_16;
	public static String ZeroMQNetworkService_2;
	public static String ZeroMQNetworkService_20;
	public static String ZeroMQNetworkService_3;
	public static String ZeroMQNetworkService_4;
	public static String ZeroMQNetworkService_5;
	public static String ZeroMQNetworkService_6;
	public static String ZeroMQNetworkService_7;
	public static String ZeroMQNetworkService_8;
	public static String ZeroMQNetworkService_9;
	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}

==> io.janusproject.plugin-0.10.1-sources.jar: io/janusproject/kernel/services/zeromq/Messages.java <==
/*
 * $Id$
 *
 * SARL is an general-purpose agent programming language.
 * More details on http://www.sarl.io
 *
 * Copyright (C) 2014-2019 the original authors or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.janusproject.kernel.services.zeromq;

import org.eclipse.osgi.util.NLS;

/** Messages.
 * @author $Author: sgalland$
 * @version $FullVersion$
 * @mavengroupid $GroupId$
 * @mavenartifactid $ArtifactId$
 * @ExcludeFromApidoc
 */
@SuppressWarnings("all")
public class Messages extends NLS {
	private static final String BUNDLE_NAME = Messages.class.getPackage().getName() + ".messages"; //$NON-NLS-1$
	public static String ZeroMQNetworkService_0;
	public static String ZeroMQNetworkService_1;
	public static String ZeroMQNetworkService_10;
	public static String ZeroMQNetworkService_11;
	public static String ZeroMQNetworkService_12;
	public static String ZeroMQNetworkService_13;
	public static String ZeroMQNetworkService_14;
	public static String ZeroMQNetworkService_15;
	public static String ZeroMQNetworkService_16;
	public static String ZeroMQNetworkService_17;
	public static String ZeroMQNetworkService_2;
	public static String ZeroMQNetworkService_20;
	public static String ZeroMQNetworkService_3;
	public static String ZeroMQNetworkService_4;
	public static String ZeroMQNetworkService_5;
	public static String ZeroMQNetworkService_6;
	public static String ZeroMQNetworkService_7;
	public static String ZeroMQNetworkService_8;
	public static String ZeroMQNetworkService_9;
	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}
